@@ -8,7 +8,7 @@
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2011-2012, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2013, Takazumi Shirayanagi\n
  * The new BSD License is applied to this software.
  * see LICENSE
 */
@@ -19,7 +19,7 @@
 
 //======================================================================
 // include
-#include "iutest_charcode.hpp"
+#include "../iutest_env.hpp"
 #include "iutest_constant.hpp"
 
 namespace iutest {
@@ -27,34 +27,15 @@ namespace detail
 {
 
 //======================================================================
-// function
+// declare
 /**
  * @brief	t@CƍsԍA𐶐(RpCl)
 */
-inline ::std::string FormatFileLocation(const char* file, int line)
-{
-	const char* const file_name = file == NULL ? kStrings::UnkownFile : file;
-	if( line < 0 ) return file;
-	iuStringStream::type strm;
-#ifdef _MSC_VER
-	strm << file_name << "(" << line << ")";
-#else
-	strm << file_name << ":" << line;
-#endif
-	return strm.str();
-}
-
+::std::string FormatFileLocation(const char* file, int line);
 /**
  * @brief	t@CƍsԍA𐶐
 */
-inline ::std::string FormatCompilerIndependentFileLocation(const char* file, int line)
-{
-	const char* const file_name = file == NULL ? kStrings::UnkownFile : file;
-	if( line < 0 ) return file;
-	iuStringStream::type strm;
-	strm << file_name << ":" << line;
-	return strm.str();
-}
+::std::string FormatCompilerIndependentFileLocation(const char* file, int line);
 
 //======================================================================
 // class
@@ -72,7 +53,7 @@ public:
 	const char*		message(void)	const	{ return m_message.c_str(); }	//!< bZ[W̎擾
 
 public:
-	::std::string GetString(void)	const { return m_message; }
+	::std::string GetString(void)	const	{ return m_message; }
 public:
 	template<typename T>
 	iuMessage&	operator << (const T& value) 
@@ -82,6 +63,7 @@ public:
 		m_message += strm.str();
 		return *this;
 	}
+#if !defined(IUTEST_NO_ARGUMENT_DEPENDENT_LOOKUP)
 	template<typename T>
 	iuMessage&	operator << (T* const& value) 
 	{
@@ -97,6 +79,7 @@ public:
 		}
 		return *this;
 	}
+#endif
 	iuMessage&	operator << (bool b) 
 	{
 		m_message += b ? "true" : "false";
@@ -131,22 +114,9 @@ public:
 	/**
 	 * @brief	bZ[W̒ǋL
 	*/
-	void	add_message(const char* str)
-	{
-		append(str);
-	}
+	void	add_message(const char* str) { append(str); }
 private:
-	void	append(const char* str)
-	{
-		if( str == NULL )
-		{
-			m_message += "(null)";
-		}
-		else
-		{
-			m_message += str;
-		}
-	}
+	void	append(const char* str);
 };
 
 inline iu_ostream& operator << (iu_ostream& os, const iuMessage& msg)
@@ -189,13 +159,7 @@ public:
 	int				line_number(void)	const	{ return m_line; }				//!< Cԍ̎擾
 public:
 	/** @private */
-	::std::string	make_message(void) const
-	{
-		::std::string str = FormatFileLocation(m_file, m_line);
-		str += ": ";
-		str += message();
-		return str;
-	}
+	::std::string	make_message(void) const;
 	::std::string	make_newline_message(void) const
 	{
 		return make_message() + "\n";
@@ -205,4 +169,8 @@ public:
 }	// end of namespace detail
 }	// end of namespace iutest
 
+#if !IUTEST_HAS_LIB
+#  include "../impl/iutest_message.ipp"
+#endif
+
 #endif
