@@ -8,7 +8,7 @@
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2012, Takazumi Shirayanagi\n
+ * Copyright (C) 2012-2013, Takazumi Shirayanagi\n
  * The new BSD License is applied to this software.
  * see LICENSE
 */
@@ -162,6 +162,27 @@ namespace iutest {
 #  define IUTEST_HAS_CXX11_HDR_CHRONO	0
 #endif
 
+// random
+#ifndef IUTEST_HAS_CXX_HDR_RANDOM
+
+#if		defined(__GLIBCXX__)
+#  if defined(__GNUC__)
+#    if (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 5)) && defined(__GXX_EXPERIMENTAL_CXX0X__)
+#      define IUTEST_HAS_CXX_HDR_RANDOM		1
+#    endif
+#  else
+#  endif
+#elif	defined(_MSC_VER)
+#  if _MSC_VER > 1600
+#    define IUTEST_HAS_CXX_HDR_RANDOM		1
+#  endif
+#endif
+
+#endif
+
+#ifndef IUTEST_HAS_CXX_HDR_RANDOM
+#  define IUTEST_HAS_CXX_HDR_RANDOM		0
+#endif
 
 // abi
 #ifndef IUTEST_HAS_HDR_CXXABI
@@ -178,6 +199,17 @@ namespace iutest {
 #  define IUTEST_HAS_HDR_CXXABI			0
 #endif
 
+// sys/time.h
+#ifndef IUTEST_HAS_HDR_SYSTIME
+#  if defined(IUTEST_OS_WINDOWS) && !defined(IUTEST_OS_WINDOWS_MINGW)
+#    define IUTEST_HAS_HDR_SYSTIME		0
+#  endif
+#endif
+
+#ifndef IUTEST_HAS_HDR_SYSTIME
+#  define IUTEST_HAS_HDR_SYSTIME		1
+#endif
+
 namespace iutest {
 namespace detail
 {
@@ -192,6 +224,9 @@ inline int iu_mbtowc(wchar_t* dst, const char* src, size_t size)
 {
 #if defined(IUTEST_OS_LINUX_ANDROID) || defined(IUTEST_OS_WINDOWS_MOBILE)
 	// unimplimented
+	IUTEST_UNUSED_VAR(dst);
+	IUTEST_UNUSED_VAR(src);
+	IUTEST_UNUSED_VAR(size);
 	return 0;
 #else
 	return mbtowc(dst, src, size);
