@@ -8,7 +8,7 @@
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2011-2012, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2013, Takazumi Shirayanagi\n
  * The new BSD License is applied to this software.
  * see LICENSE
  * 
@@ -28,6 +28,7 @@
 #include "iutest_typed_tests.hpp"
 #include "iutest_prod.hpp"
 #include "iutest_static_assertion.hpp"
+#include "iutest_ignore.hpp"
 #include "listener/iutest_default_printer.hpp"
 #include "listener/iutest_default_xml_generator.hpp"
 
@@ -386,12 +387,20 @@ namespace iutest
 
 /**
  * @ingroup	IUTEST_ASSERT_
- * @brief	no new failure eXg
+ * @brief	no new fatal failure eXg
 */
 #ifndef IUTEST_ASSERT_NO_FATAL_FAILURE
 #  define IUTEST_ASSERT_NO_FATAL_FAILURE(statement)	IUTEST_TEST_NO_FATAL_FAILURE_(statement, IUTEST_ASSERT_FAILURE)
 #endif
 
+/**
+ * @ingroup	IUTEST_ASSERT_
+ * @brief	no new failure eXg
+*/
+#ifndef IUTEST_ASSERT_NO_FAILURE
+#  define IUTEST_ASSERT_NO_FAILURE(statement)		IUTEST_TEST_NO_FAILURE_(statement, IUTEST_ASSERT_FAILURE)
+#endif
+
 /**
  * @ingroup	IUTEST_ASSERT_
  * @brief	IȎs
@@ -631,12 +640,20 @@ namespace iutest
 
 /**
  * @ingroup	IUTEST_EXPECT_
- * @brief	no new failure eXg
+ * @brief	no new fatal failure eXg
 */
 #ifndef IUTEST_EXPECT_NO_FATAL_FAILURE
 #  define IUTEST_EXPECT_NO_FATAL_FAILURE(statement)	IUTEST_TEST_NO_FATAL_FAILURE_(statement, IUTEST_EXPECT_FAILURE)
 #endif
 
+/**
+ * @ingroup	IUTEST_EXPECT_
+ * @brief	no new failure eXg
+*/
+#ifndef IUTEST_EXPECT_NO_FAILURE
+#  define IUTEST_EXPECT_NO_FAILURE(statement)		IUTEST_TEST_NO_FAILURE_(statement, IUTEST_EXPECT_FAILURE)
+#endif
+
 /**
  * @ingroup	IUTEST_EXPECT_
  * @brief	IȎs
@@ -882,6 +899,14 @@ namespace iutest
 
 #endif
 
+/**
+ * @ingroup	IUTEST_INFORM_
+ * @brief	no new fatal failure eXg
+*/
+#ifndef IUTEST_INFORM_NO_FAILURE
+#  define IUTEST_INFORM_NO_FAILURE(statement)		IUTEST_TEST_NO_FAILURE_(statement, IUTEST_INFORM_FAILURE)
+#endif
+
 /**
  * @ingroup	IUTEST_INFORM_
  * @brief	no new failure eXg
@@ -924,6 +949,8 @@ private:
 #endif
 		TestEnv::event_listeners().set_default_result_printer(new DefalutResultPrintListener());
 	}
+public:
+	/** @private */
 	~UnitTestSource(void)
 	{
 		{
