@@ -40,7 +40,7 @@ typedef detail::iuMessage	Message;
 /**
  * @brief	eXg
 */
-class AssertionResult : public Message
+class AssertionResult
 {
 public:
 	/**
@@ -49,7 +49,7 @@ public:
 	*/
 	AssertionResult(bool result) : m_result(result) {}
 	//! Rs[RXgN^
-	AssertionResult(const AssertionResult& rhs) : Message(rhs), m_result(rhs.m_result) {}
+	AssertionResult(const AssertionResult& rhs) : m_message(rhs.m_message), m_result(rhs.m_result) {}
 
 	/**
 	 * @brief	
@@ -59,6 +59,12 @@ public:
 	/**
 	 * @brief	bZ[W̎擾
 	*/
+	const char*		message(void)	const	{ return m_message.message(); }
+
+	/**
+	 * @brief	bZ[W̎擾
+	 * @deprecated please use message() instead.
+	*/
 	const char* failure_message(void) const { return message(); }
 
 	/** @private */
@@ -71,7 +77,7 @@ public:
 	template<typename T>
 	AssertionResult&		operator << (T value)
 	{
-		Message::operator << (value);
+		m_message << (value);
 		return *this;
 	}
 
@@ -86,9 +92,30 @@ public:
 	static AssertionResult	Failure(void)	{ return AssertionResult(false); }
 
 private:
+	IUTEST_PP_DISALLOW_ASSIGN(AssertionResult);
+
+	Message m_message;
 	bool	m_result;
 };
 
+#if IUTEST_HAS_ASSERTION_RETURN
+/**
+ * @brief	Assetion Return Type
+*/
+template<typename R>
+struct AssertionReturn
+{
+	R value;	//!< ߂l
+	//! RXgN^
+	AssertionReturn() {}
+	/**
+	 * @brief	RXgN^
+	 * @param [in]	v : ߂l̒l
+	*/
+	AssertionReturn(const R& v) : value(v) {}
+};
+#endif
+
 /**
  * @brief	Assertion \zNX
 */
@@ -115,11 +142,21 @@ public:
 	typedef detail::iu_list<ScopedMessage> msg_list;
 
 private:
-	template<typename T=void>
+	template<typename T>
 	struct List {
 		static msg_list s_scoped_message;
 	};
-	typedef List<>	MessageList;
+	typedef List<void>	MessageList;
+
+#if defined(IUTEST_NO_PRIVATE_IN_AGGREGATE)
+	friend class ScopedMessage;
+#endif
+
+#if IUTEST_HAS_ASSERTION_RETURN
+private:
+	template<typename R>struct ReturnTypedFixed;
+#endif
+
 public:
 	/** @private */
 	class Fixed : public Message {
@@ -130,7 +167,25 @@ public:
 			Message::operator << (value);
 			return *this;
 		}
+#if IUTEST_HAS_ASSERTION_RETURN
+		template<typename R>
+		ReturnTypedFixed<R> operator << (const AssertionReturn<R>& ret)
+		{
+			return ReturnTypedFixed<R>(*this, ret);
+		}
+#endif
 	};
+
+#if IUTEST_HAS_ASSERTION_RETURN
+private:
+	template<typename R>
+	struct ReturnTypedFixed {
+		Fixed fixed;
+		AssertionReturn<R> ret;
+		ReturnTypedFixed(const Fixed& f, const AssertionReturn<R>& r) : fixed(f), ret(r) {}
+	};
+#endif
+
 public:
 	/**
 	 * @brief	RXgN^
@@ -157,8 +212,8 @@ private:
 	IUTEST_PP_DISALLOW_COPY_AND_ASSIGN(AssertionHelper);
 
 #if IUTEST_HAS_RVALUE_REFS
-	AssertionHelper(AssertionHelper&& rhs) IUTEST_DECL_DELETED_FUNCTION;
-	AssertionHelper& operator=(AssertionHelper&&) IUTEST_DECL_DELETED_FUNCTION;
+	AssertionHelper(AssertionHelper&& rhs) IUTEST_CXX_DELETED_FUNCTION;
+	AssertionHelper& operator=(AssertionHelper&&) IUTEST_CXX_DELETED_FUNCTION;
 #endif
 
 public:
@@ -172,6 +227,15 @@ public:
 		}
 #endif
 	}
+#if IUTEST_HAS_ASSERTION_RETURN
+	/** @private */
+	template<typename R>
+	R	operator = (const ReturnTypedFixed<R>& fixed)
+	{
+		this->operator=(fixed.fixed);
+		return fixed.ret.value;
+	}	
+#endif
 
 private:
 	void	OnFixed(const Fixed& fixed) throw()
@@ -215,8 +279,13 @@ private:
 	TestPartResult m_part_result;
 };
 
+}	// end of namespace iutest
+
 template<typename T>
-AssertionHelper::msg_list AssertionHelper::List<T>::s_scoped_message;
+::iutest::AssertionHelper::msg_list iutest::AssertionHelper::List<T>::s_scoped_message;
+
+namespace iutest
+{
 
 //======================================================================
 // function
@@ -279,10 +348,9 @@ inline AssertionResult EqFailure(const char* expected_expression, const char* ac
  * @private
  * @{
 */
-#define COMPARE_HELPER(op_name, op)															\
-	template<typename T1, typename T2>														\
-	inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelper##op_name(const char* expr1, const char* expr2		\
-													, const T1& val1, const T2& val2) {		\
+#define DECL_COMPARE_HELPER_I_(op_name, op, type1, type2)									\
+	inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelper##op_name(						\
+			const char* expr1, const char* expr2, type1 val1, type2 val2) {					\
 	if( val1 op val2 ) return AssertionSuccess();											\
 	else {																					\
 	return AssertionFailure() << "error: Expected: " << expr1 << " " #op " " << expr2		\
@@ -290,23 +358,30 @@ inline AssertionResult EqFailure(const char* expected_expression, const char* ac
 		<< " vs " << FormatForComparisonFailureMessage(val2, val1);							\
 	}																						\
 	}																						\
-	inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelper##op_name(const char* expr1, const char* expr2		\
-												, BiggestInt val1, BiggestInt val2)	{		\
-	if( val1 op val2 ) return AssertionSuccess();											\
-	else {																					\
-	return AssertionFailure() << "error: Expected: " << expr1 << " " #op " " << expr2		\
-		<< "\n  Actual: " << FormatForComparisonFailureMessage(val1, val2)					\
-		<< " vs " << FormatForComparisonFailureMessage(val2, val1);							\
-	}																						\
-}
 
-COMPARE_HELPER(NE, !=)
-COMPARE_HELPER(LE, <=)
-COMPARE_HELPER(LT, < )
-COMPARE_HELPER(GE, >=)
-COMPARE_HELPER(GT, > )
+#if !defined(IUTEST_NO_FUNCTION_TEMPLATE_ORDERING)
 
-#undef COMPARE_HELPER
+#define DECL_COMPARE_HELPER_(op_name, op)							\
+	template<typename T1, typename T2>								\
+	DECL_COMPARE_HELPER_I_(op_name, op, const T1&, const T2&)		\
+	DECL_COMPARE_HELPER_I_(op_name, op, BiggestInt, BiggestInt)
+
+#else
+
+#define DECL_COMPARE_HELPER_(op_name, op)							\
+	template<typename T1, typename T2>								\
+	DECL_COMPARE_HELPER_I_(op_name, op, const T1&, const T2&)
+
+#endif
+
+DECL_COMPARE_HELPER_(NE, !=)
+DECL_COMPARE_HELPER_(LE, <=)
+DECL_COMPARE_HELPER_(LT, < )
+DECL_COMPARE_HELPER_(GE, >=)
+DECL_COMPARE_HELPER_(GT, > )
+
+#undef DECL_COMPARE_HELPER_I_
+#undef DECL_COMPARE_HELPER_
 
 /**
  * @}
@@ -383,6 +458,7 @@ template<>
 class EqHelper<true>
 {
 public:
+#if !defined(IUTEST_NO_SFINAE)
 	template<typename T1, typename T2>
 	static AssertionResult Compare(const char* expr1, const char* expr2, const T1& val1, const T2& val2
 		, typename detail::enable_if< !detail::is_pointer<T2>::value, void>::type*& = detail::enabler::value)
@@ -395,6 +471,13 @@ public:
 		IUTEST_UNUSED_VAR(val1);
 		return CmpHelperEQ(expr1, expr2, static_cast<T2*>(NULL), val2);
 	}
+#else
+	template<typename T1, typename T2>
+	static AssertionResult Compare(const char* expr1, const char* expr2, const T1& val1, const T2& val2)
+	{
+		return CmpHelperEQ(expr1, expr2, (T2)val1, val2);
+	}
+#endif
 };
 
 /**
@@ -463,6 +546,7 @@ template<>
 class NeHelper<true>
 {
 public:
+#if !defined(IUTEST_NO_SFINAE)
 	template<typename T1, typename T2>
 	static AssertionResult Compare(const char* expr1, const char* expr2, const T1& val1, const T2& val2
 		, typename detail::enable_if< !detail::is_pointer<T2>::value, void>::type*& = detail::enabler::value)
@@ -475,6 +559,13 @@ public:
 		IUTEST_UNUSED_VAR(val1);
 		return CmpHelperNE(expr1, expr2, static_cast<T2*>(NULL), val2);
 	}
+#else
+	template<typename T1, typename T2>
+	static AssertionResult Compare(const char* expr1, const char* expr2, const T1& val1, const T2& val2)
+	{
+		return CmpHelperNE(expr1, expr2, (T2)val1, val2);
+	}
+#endif
 };
 
 template<typename RawType>
@@ -494,6 +585,7 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ DoubleNearPredFormat(const char*
 {
 	return CmpHelperNearFloatingPoint(expr1, expr2, absc, val1, val2, abs_v);
 }
+#if !defined(IUTEST_NO_ARGUMENT_DEPENDENT_LOOKUP)
 template<typename T, typename A>
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperNear(const char* expr1, const char* expr2, const char* absc
 													, const T& val1, const T& val2, const A& abs_v)
@@ -509,6 +601,7 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperNear(const char* expr1,
 {
 	return CmpHelperNearFloatingPoint<double>(expr1, expr2, absc, val1, val2, static_cast<double>(abs_v));
 }
+#endif
 template<typename A>
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperNear(const char* expr1, const char* expr2, const char* absc
 													, float val1, float val2, const A& abs_v)
