@@ -75,16 +75,21 @@
 #endif
 
 #ifndef IUTEST_HAS_PARAM_TEST
-#  define IUTEST_HAS_PARAM_TEST		1	//!< lp[^eXggp\ǂ
+#  define IUTEST_HAS_PARAM_TEST			1	//!< lp[^eXggp\ǂ
 #endif
 
 #ifndef IUTEST_HAS_TYPED_TEST
-#  define IUTEST_HAS_TYPED_TEST		1	//!< ^teXggp\ǂ
+//! ^teXggp\ǂ
+#  if !defined(IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION)
+#    define IUTEST_HAS_TYPED_TEST		1
+#  else
+#    define IUTEST_HAS_TYPED_TEST		0
+#  endif
 #endif
 
 #ifndef IUTEST_HAS_TYPED_TEST_P
 //! ^p[^eXggp\ǂ
-#  if IUTEST_HAS_TYPED_TEST && !defined(IUTEST_NO_VARIADIC_MACROS)
+#  if IUTEST_HAS_TYPED_TEST && !defined(IUTEST_NO_VARIADIC_MACROS) && !defined(IUTEST_NO_TEMPLATE_TEMPLATES)
 #    define IUTEST_HAS_TYPED_TEST_P	1
 #  else
 #    define IUTEST_HAS_TYPED_TEST_P	0
@@ -114,6 +119,24 @@
 #  endif
 #endif
 
+#ifndef IUTEST_HAS_VALUESGEN
+//! ::iutest::ValuesGen gp\ǂ
+#  if IUTEST_HAS_PARAM_TEST
+#    define IUTEST_HAS_VALUESGEN	1
+#  else
+#    define IUTEST_HAS_VALUESGEN	0
+#  endif
+#endif
+
+#ifndef IUTEST_HAS_RANDOMVALUES
+//! ::iutest::RandomValues gp\ǂ
+#  if IUTEST_HAS_PARAM_TEST && IUTEST_HAS_VALUESGEN
+#    define IUTEST_HAS_RANDOMVALUES	1
+#  else
+#    define IUTEST_HAS_RANDOMVALUES	0
+#  endif
+#endif
+
 #ifndef IUTEST_HAS_COMBINE
 //! ::iutest::Combine gp\ǂ
 #  if IUTEST_HAS_PARAM_TEST && IUTEST_HAS_TUPLE
@@ -164,7 +187,11 @@
  * @brief	ASSERT }NŎsɗO throw ܂B
  * @note	Tu֐ɃAT[VLqĂA̎_ŃeXgf悤ɂȂ܂
 */
-#  define IUTEST_USE_THROW_ON_ASSERT_FAILURE	0
+#  if !defined(IUTEST_NO_VOID_RETURNS)
+#    define IUTEST_USE_THROW_ON_ASSERT_FAILURE	0
+#  else
+#    define IUTEST_USE_THROW_ON_ASSERT_FAILURE	1
+#  endif
 #endif
 
 #ifndef IUTEST_HAS_SPI_LAMBDA_SUPPORT
@@ -181,12 +208,18 @@
 #endif
 
 #ifndef IUTEST_HAS_PACKAGE
-#  define IUTEST_HAS_PACKAGE		1	//!< pbP[W@\邩ǂ
+//! pbP[W@\邩ǂ
+#  if !defined(IUTEST_NO_ARGUMENT_DEPENDENT_LOOKUP)
+#    define IUTEST_HAS_PACKAGE		1
+#  else
+#    define IUTEST_HAS_PACKAGE		0
+#  endif
 #endif
 
 // peep
 #ifndef IUTEST_HAS_PEEP
-#  define IUTEST_HAS_PEEP			1	//!< private o[ւ̃ANZX}Ngp\ǂ
+//! private o[ւ̃ANZX}Ngp\ǂ
+#  define IUTEST_HAS_PEEP			1
 #endif
 
 #ifndef IUTEST_HAS_PEEP_FUNC
@@ -207,6 +240,33 @@
 #  endif
 #endif
 
+#ifndef IUTEST_HAS_STATIC_ASSERT_TYPEEQ
+//! StaticAssertTypeEq gp\ǂ
+#if !defined(IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION)
+#    define IUTEST_HAS_STATIC_ASSERT_TYPEEQ		1
+#  else
+#    define IUTEST_HAS_STATIC_ASSERT_TYPEEQ		0
+#  endif
+#endif
+
+#ifndef IUTEST_HAS_PRINT_TO
+//! PrintTo gp\ǂ
+#  if !defined(IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION) && !defined(IUTEST_NO_FUNCTION_TEMPLATE_ORDERING)
+#    define IUTEST_HAS_PRINT_TO		1
+#  else
+#    define IUTEST_HAS_PRINT_TO		0
+#  endif
+#endif
+
+#ifndef IUTEST_HAS_ASSERTION_RETURN
+//! ::iutest::AssertionReturn gp\ǂ
+#  if !defined(IUTEST_NO_FUNCTION_TEMPLATE_ORDERING)
+#    define IUTEST_HAS_ASSERTION_RETURN		1
+#  else
+#    define IUTEST_HAS_ASSERTION_RETURN		0
+#  endif
+#endif
+
 /**
  * @}
 */
@@ -281,7 +341,12 @@
 */
 
 #ifndef IUTEST_HAS_STRINGSTREAM
-#  define IUTEST_HAS_STRINGSTREAM	1	//!< std::stringstream gp\ǂ
+//! std::stringstream gp\ǂ
+#  if !defined(_STLP_NO_IOSTREAMS)
+#    define IUTEST_HAS_STRINGSTREAM	1	
+#  else
+#    define IUTEST_HAS_STRINGSTREAM	0
+#  endif
 #endif
 
 /**
