@@ -8,7 +8,7 @@
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2011-2012, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2013, Takazumi Shirayanagi\n
  * The new BSD License is applied to this software.
  * see LICENSE
 */
@@ -20,6 +20,7 @@
 //======================================================================
 // include
 #include "internal/iutest_compiler.hpp"
+#include "internal/iutest_pp.hpp"
 #include "internal/iutest_stdlib.hpp"
 #include "iutest_config.hpp"
 #include <stdio.h>
@@ -91,25 +92,7 @@ class floating_point
 private:
 	typedef floating_point<RawType>	_Myt;
 
-	template<typename T, typename DMY>
-	struct impl				 { typedef detail::type_least_t<4>	type; };
-	template<typename DMY>
-	struct impl<double, DMY> { typedef detail::type_least_t<8>	type; };
-
-	template<typename T, typename DMY>
-	struct ieee 
-	{
-		static const int EXP	= 8;
-		static const int FRAC	= 23;
-	};
-	template<typename DMY>
-	struct ieee<double, DMY>
-	{
-		static const int EXP	= 11;
-		static const int FRAC	= 52;
-	};
-
-	typedef typename impl<RawType, void>::type	type;
+	typedef typename detail::type_least_t<sizeof(RawType)>	type;
 	typedef typename type::Int	Int;
 	typedef typename type::UInt	UInt;
 	union FInt
@@ -119,9 +102,6 @@ private:
 		RawType	fv;
 	};
 
-	static const int EXP	= ieee<RawType, void>::EXP;
-	static const int FRAC	= ieee<RawType, void>::FRAC;
-
 public:
 	/**
 	 * @brief	RXgN^
@@ -144,8 +124,8 @@ public:
 	 * @brief	RXgN^
 	*/
 	floating_point(const _Myt& rhs)
+		: m_v(rhs.m_v)
 	{
-		m_v.uv = rhs.m_v.uv;
 	}
 
 public:
@@ -226,7 +206,33 @@ public:
 	bool	operator == (const _Myt& rhs) const	{ return m_v.uv == rhs.m_v.uv; }	//!< r
 
 private:
-	static const Int	kMaxUlps = 4;
+	template<size_t N, typename DMY>
+	struct ieee 
+	{
+		enum
+		{
+			  EXP  = 8
+			, FRAC = 23
+		};
+	};
+	template<typename DMY>
+	struct ieee<8, DMY>
+	{
+		enum
+		{
+			  EXP  = 11
+			, FRAC = 52
+		};
+	};
+	enum
+	{
+		  EXP  = ieee<sizeof(RawType), void>::EXP
+		, FRAC = ieee<sizeof(RawType), void>::FRAC
+	};
+	enum
+	{
+		kMaxUlps = 4
+	};
 private:
 	FInt	m_v;
 };
@@ -258,7 +264,7 @@ template<typename TN>bool TestTypeIdHelper<TN>::_dummy = false;
   * @brief	TypeId Generator
 */
 template<typename TN>
-inline IUTEST_CONSTEXPR TypeId	GetTypeId(void)
+inline IUTEST_CXX_CONSTEXPR TypeId	GetTypeId(void)
 {
 	return &(helper::TestTypeIdHelper<TN>::_dummy);
 }
@@ -267,7 +273,7 @@ inline IUTEST_CONSTEXPR TypeId	GetTypeId(void)
   * @internal
   * @brief	TypeId Generator
 */
-inline IUTEST_CONSTEXPR TypeId	GetTestTypeId(void)
+inline IUTEST_CXX_CONSTEXPR TypeId	GetTestTypeId(void)
 {
 	return 0;
 }
