@@ -173,7 +173,10 @@ private:
 	};
 
 private:
-	friend	class TestEnv;
+	friend class TestEnv;
+#if defined(IUTEST_NO_PRIVATE_IN_AGGREGATE)
+	friend class ScopedGuard;
+#endif
 
 	int m_test_flags;
 };
@@ -307,6 +310,13 @@ public:
 		}
 	} filter;
 
+#if defined(IUTEST_NO_PRIVATE_IN_AGGREGATE)
+	friend class FilterOption;
+	friend class RandomSeedSet;
+	friend class RepeatCountSet;
+	friend class ColorOptionSet;
+#endif
+
 private:
 	struct Variable
 	{
@@ -430,7 +440,7 @@ private:
 	template<typename CharType>
 	static bool	ParseCommandLineElem(CharType* argv)
 	{
-		typedef typename detail::mbs_ptr<CharType>::type formatter;
+		typedef typename detail::mbs_ptr<CharType> formatter;
 
 		formatter argv_format;
 		const char* str = argv_format.ptr(argv);
