@@ -8,7 +8,7 @@
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2011-2012, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2013, Takazumi Shirayanagi\n
  * The new BSD License is applied to this software.
  * see LICENSE
 */
@@ -58,18 +58,31 @@
 #define IIUT_TYPED_TEST_CASE_(testcase_, types_)		\
 	typedef ::iutest::detail::TypeList< types_ >::type	IUTEST_TYPED_TEST_PARAMS_(testcase_)
 
-#define IIUT_TYPED_TEST_(testcase_, testname_)									\
-	template<typename iutest_TypeParam>											\
+#define IIUT_TYPED_TEST_(testcase_, testname_)										\
+	template<typename iutest_TypeParam>												\
 	class IUTEST_TEST_CLASS_NAME_(testcase_, testname_) : public testcase_<iutest_TypeParam> {		\
-		typedef testcase_<iutest_TypeParam> TestFixture;						\
-		typedef iutest_TypeParam	TypeParam;									\
-		protected: virtual void Body(void);										\
-	};																			\
+		typedef testcase_<iutest_TypeParam> TestFixture;							\
+		typedef iutest_TypeParam	TypeParam;										\
+		protected: virtual void Body(void);											\
+	};																				\
 	::iutest::detail::TypeParamTestInstance< IUTEST_TEST_CLASS_NAME_(testcase_, testname_), IUTEST_TYPED_TEST_PARAMS_(testcase_) >	\
 	s_##testcase_##_##testname_( IUTEST_CONCAT_PACKAGE_(testcase_), #testname_);	\
 	template<typename iutest_TypeParam>												\
 	void IUTEST_TEST_CLASS_NAME_(testcase_, testname_)<iutest_TypeParam>::Body(void)
 
+#define IIUT_TYPED_TEST_IGNORE_(testcase_, testname_)								\
+	template<typename iutest_TypeParam>												\
+	class IUTEST_TEST_CLASS_NAME_(testcase_, testname_) : public testcase_<iutest_TypeParam> {		\
+		typedef testcase_<iutest_TypeParam> TestFixture;							\
+		typedef iutest_TypeParam	TypeParam;										\
+		protected: virtual void Body(void) { IUTEST_SKIP() << "ignored test..."; }	\
+		template<typename T>void Body(void);										\
+	};																				\
+	::iutest::detail::TypeParamTestInstance< IUTEST_TEST_CLASS_NAME_(testcase_, testname_), IUTEST_TYPED_TEST_PARAMS_(testcase_) >	\
+	s_##testcase_##_##testname_( IUTEST_CONCAT_PACKAGE_(testcase_), #testname_);	\
+	template<typename iutest_TypeParam>												\
+	template<typename T>void IUTEST_TEST_CLASS_NAME_(testcase_, testname_)<iutest_TypeParam>::Body(void)
+
 /**
  * @}
 */
@@ -133,21 +146,36 @@
 		typedef iutest_TypeParam	TypeParam;					\
 		protected: virtual void Body(void);						\
 	};															\
-	static int s_iutest_##testname_##_defined_dummy_ IUTEST_ATTRIBUTE_UNUSED_ =	\
+	static const int s_iutest_##testname_##_defined_dummy_ IUTEST_ATTRIBUTE_UNUSED_ =	\
 	IUTEST_TYPED_TEST_CASE_PSTATE_NAME_(testcase_).AddTestName(__FILE__, __LINE__, #testcase_, #testname_);		\
 	}															\
 	template<typename iutest_TypeParam>							\
 	void IUTEST_TYPED_TEST_P_NAMESPACE_(testcase_)::testname_<iutest_TypeParam>::Body(void)
 
+#define IUTEST_TYPED_TEST_P_IGNORE_(testcase_, testname_)		\
+	namespace IUTEST_TYPED_TEST_P_NAMESPACE_(testcase_) {		\
+	template<typename iutest_TypeParam>							\
+	class testname_ : public testcase_<iutest_TypeParam> {		\
+		typedef testcase_<iutest_TypeParam> TestFixture;		\
+		typedef iutest_TypeParam	TypeParam;					\
+		protected: virtual void Body(void) { IUTEST_SKIP() << "ignored test..."; }		\
+		template<typename T>void Body(void);					\
+	};															\
+	static const int s_iutest_##testname_##_defined_dummy_ IUTEST_ATTRIBUTE_UNUSED_ =	\
+	IUTEST_TYPED_TEST_CASE_PSTATE_NAME_(testcase_).AddTestName(__FILE__, __LINE__, #testcase_, #testname_);		\
+	}															\
+	template<typename iutest_TypeParam>template<typename T>		\
+	void IUTEST_TYPED_TEST_P_NAMESPACE_(testcase_)::testname_<iutest_TypeParam>::Body(void)
+
 #define IUTEST_REGISTER_TYPED_TEST_CASE_P_(testcase_, ...)								\
 	namespace IUTEST_TYPED_TEST_P_NAMESPACE_(testcase_) {								\
 		typedef ::iutest::detail::Templates< __VA_ARGS__ >::type	iutest_AllTests_;	\
 	}																					\
-	static bool s_iutest_##testcase_##_register_dummy_ IUTEST_ATTRIBUTE_UNUSED_ =		\
+	static const bool s_iutest_##testcase_##_register_dummy_ IUTEST_ATTRIBUTE_UNUSED_ =	\
 	IUTEST_TYPED_TEST_CASE_PSTATE_NAME_(testcase_).VerifyTestNames(__FILE__, __LINE__, #__VA_ARGS__)
 
 #define IUTEST_INSTANTIATE_TYPED_TEST_CASE_P_(prefix_, testcase_, types_)	\
-	bool iutest_##prefix_##_##testcase_ IUTEST_ATTRIBUTE_UNUSED_ =			\
+	const bool iutest_##prefix_##_##testcase_ IUTEST_ATTRIBUTE_UNUSED_ =	\
 		::iutest::detail::TypeParameterizedTestCase< testcase_				\
 		, IUTEST_TYPED_TEST_P_NAMESPACE_(testcase_)::iutest_AllTests_		\
 		, ::iutest::detail::TypeList< types_ >::type >::Register(#prefix_, IUTEST_CONCAT_PACKAGE_(testcase_)	\
@@ -181,7 +209,7 @@ class TypeParamTestInstance
 	/**
 	 * @brief	eeXg̃CX^X
 	*/
-	template<typename TT, typename DMY=void>
+	template<typename TT, typename DMY>
 	class EachTest
 	{
 		typedef typename TT::Head			TypeParam;
@@ -192,6 +220,7 @@ class TypeParamTestInstance
 		EachTest(const char* testcase, const char* name, int index)
 			: m_mediator(UnitTest::instance().AddTestCase<_MyTestCase>(
 				detail::MakeIndexTestName(testcase, index).c_str()
+				//detail::MakeTypedTestName<TypeParam>(testcase, index).c_str()
 				, internal::GetTypeId<detail::None>()	// TypeId 𓝈ꂷ邽߃_~[n
 				, TestBody::SetUpTestCase
 				, TestBody::TearDownTestCase))
@@ -212,7 +241,7 @@ class TypeParamTestInstance
 		TestInfo					m_info;
 		detail::iuFactory<TestBody>	m_factory;
 
-		EachTest<typename TT::Tail>	m_next;
+		EachTest<typename TT::Tail, void>	m_next;
 	};
 
 	// I[
@@ -233,7 +262,7 @@ public:
 	}
 
 private:
-	EachTest<TypeParams>	m_tests;
+	EachTest<TypeParams, void>	m_tests;
 
 	IUTEST_PP_DISALLOW_COPY_AND_ASSIGN(TypeParamTestInstance);
 };
@@ -378,7 +407,9 @@ public:
 		typedef typename Tests::Head	Head;
 		typedef Fixture<Head>			FixtureClass;
 		typedef TypedTestCase<TypeParam>	_MyTestCase;
-		TestCase* testcase = UnitTest::instance().AddTestCase<_MyTestCase>(detail::MakeIndexTestName(prefix, testcase_name, index).c_str()
+		TestCase* testcase = UnitTest::instance().AddTestCase<_MyTestCase>(
+			detail::MakePrefixedIndexTestName(prefix, testcase_name, index).c_str()
+			//detail::MakePrefixedIndexTypedTestName<TypeParam>(prefix, testcase_name, index).c_str()
 			, internal::GetTypeId<FixtureClass>()
 			, FixtureClass::SetUpTestCase, FixtureClass::TearDownTestCase);
 
